# sopel-itcrowd

A Sopel plugin for IT Crowd jokes.

## Installing

Releases are hosted on PyPI, so after installing Sopel, all you need is `pip`:

```shell
$ pip install sopel-itcrowd
```

## Using

`sopel-itcrowd` provides jokes from or references to _The IT Crowd_ as commands:

* `.itnes`: The New Emergency Services
  * This command is channel-rate limited to reduce spam.

## Contributing

This plugin exists because I (dgw) had one (1) amusing idea on a weekend morning
about the New Emergency Services number. It would be silly to limit a whole
plugin to just one single joke, so I named it `itcrowd` as a container for
future expansion ideas on the same theme.

Issues suggesting more _IT Crowd_ commands and/or patches (pull requests)
implementing them are welcome!
